OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "بېرىلگەن ئىسىم بەك ئۇزۇن",
    "The given web address is too long" : "بېرىلگەن تور ئادرېسى بەك ئۇزۇن",
    "The given web address is not a valid URL" : "بېرىلگەن تور ئادرېسى ئىناۋەتلىك URL ئەمەس",
    "The given legal notice address is too long" : "بېرىلگەن قانۇن ئۇقتۇرۇشى ئادرېسى بەك ئۇزۇن",
    "The given legal notice address is not a valid URL" : "بېرىلگەن قانۇن ئۇقتۇرۇشى ئادرېسى ئىناۋەتلىك URL ئەمەس",
    "The given privacy policy address is too long" : "بېرىلگەن مەخپىيەتلىك سىياسىتى ئادرېسى بەك ئۇزۇن",
    "The given privacy policy address is not a valid URL" : "بېرىلگەن مەخپىيەتلىك سىياسىتى ئادرېسى ئىناۋەتلىك URL ئەمەس",
    "The given slogan is too long" : "بېرىلگەن شۇئار بەك ئۇزۇن",
    "The given color is invalid" : "بېرىلگەن رەڭ ئىناۋەتسىز",
    "Invalid setting key" : "تەڭشەش كۇنۇپكىسى ئىناۋەتسىز",
    "Saved" : "ساقلاندى",
    "Invalid app given" : "ئىناۋەتسىز ئەپ بېرىلگەن",
    "Invalid type for setting \"defaultApp\" given" : "بېرىلگەن \"defaultApp\" نى تەڭشەشنىڭ ئىناۋەتسىز تىپى",
    "The file was uploaded" : "ھۆججەت يۈكلەندى",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "يۈكلەنگەن ھۆججەت php.ini دىكى upload_max_filesize كۆرسەتمىسىدىن ئېشىپ كەتتى",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "يۈكلەنگەن ھۆججەت HTML شەكلىدە كۆرسىتىلگەن MAX_FILE_SIZE كۆرسەتمىسىدىن ئېشىپ كەتتى",
    "The file was only partially uploaded" : "بۇ ھۆججەت پەقەت قىسمەن يوللانغان",
    "No file was uploaded" : "ھېچقانداق ھۆججەت يۈكلەنمىدى",
    "Missing a temporary folder" : "ۋاقىتلىق قىسقۇچ كەم.",
    "Could not write file to disk" : "دىسكىغا ھۆججەت يازالمىدى",
    "A PHP extension stopped the file upload" : "PHP كېڭەيتىلمىسى ھۆججەت يوللاشنى توختاتتى",
    "No file uploaded" : "ھۆججەت يۈكلەنمىدى",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "سىز ئاللىبۇرۇن خاس ئۇسلۇبنى ئىشلىتىۋاتىسىز. تېما دېتالىنىڭ تەڭشىكى ئۇنىڭ تەرىپىدىن يېزىلغان بولۇشى مۇمكىن.",
    "Theming" : "باش تىما",
    "Appearance and accessibility" : "تاشقى كۆرۈنۈشى ۋە قولايلىقلىقى",
    "PHP Imagick module" : "PHP تەسەۋۋۇر مودۇلى",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "باش تېما دېتالى بولسىمۇ PHP مودۇلى «imagick» قوزغىتىلمىدى. Favicon ئەۋلادلىرىنىڭ نورمال ئىشلىشى ئۈچۈن ، بۇ مودۇلنى ئورنىتىشىڭىز ۋە قوزغىتىشىڭىز كېرەك.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "بۇ خىلدىكى PHP مودۇلى «تەسەۋۋۇر» SVG نى قوللىمايدۇ. تېخىمۇ ياخشى ماسلىشىش ئۈچۈن ئۇنى ئورنىتىش تەۋسىيە قىلىنىدۇ.",
    "Dark theme with high contrast mode" : "يۇقىرى سېلىشتۇرما ھالىتىدىكى قاراڭغۇ تېما",
    "Enable dark high contrast mode" : "قاراڭغۇ يۇقىرى سېلىشتۇرما ھالىتىنى قوزغىتىڭ",
    "Similar to the high contrast mode, but with dark colours." : "يۇقىرى سېلىشتۇرما ھالىتىگە ئوخشاش ، ئەمما قېنىق رەڭلەر بىلەن.",
    "Dark theme" : "قاراڭغۇ تېما",
    "Enable dark theme" : "قاراڭغۇ باشتېمىنى قوزغىتىڭ",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "ئومۇمىي يورۇقلۇق ۋە يورۇقلۇقنى تۆۋەنلىتىش ئارقىلىق كۆزىڭىزنى ئاسانلاشتۇرىدىغان قاراڭغۇ تېما.",
    "System default theme" : "سىستېما سۈكۈتتىكى باشتېما",
    "Enable the system default" : "سىستېمىنىڭ سۈكۈتتىكى ھالىتىنى قوزغىتىڭ",
    "Using the default system appearance." : "سۈكۈتتىكى سىستېما كۆرۈنۈشىنى ئىشلىتىش.",
    "Dyslexia font" : "Dyslexia خەت نۇسخىسى",
    "Enable dyslexia font" : "Dyslexia خەت نۇسخىسىنى قوزغىتىڭ",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic بىر خىل ھەقسىز خەت شەكلى / خەت نۇسخىسى بولۇپ ، ھەزىم قىلىش ئىقتىدارى تۆۋەنلەش سەۋەبىدىن كېلىپ چىققان بىر قىسىم كۆپ كۆرۈلىدىغان خاتالىقلارنى ئازايتىدۇ.",
    "High contrast mode" : "يۇقىرى سېلىشتۇرما ھالىتى",
    "Enable high contrast mode" : "يۇقىرى سېلىشتۇرما ھالىتىنى قوزغىتىڭ",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "يول باشلىشىڭىزنى ئاسانلاشتۇرىدىغان يۇقىرى سېلىشتۇرما ھالەت. كۆرۈش سۈپىتى تۆۋەنلەيدۇ ، ئەمما ئېنىقلىق دەرىجىسى ئۆستۈرۈلىدۇ.",
    "Light theme" : "يېنىك تېما",
    "Enable the default light theme" : "سۈكۈتتىكى نۇر تېمىسىنى قوزغىتىڭ",
    "The default light appearance." : "سۈكۈتتىكى نۇر كۆرۈنۈشى.",
    "Legal notice" : "قانۇن ئۇقتۇرۇشى",
    "Privacy policy" : "مەخپىيەتلىك تۈزۈمى",
    "Adjust the Nextcloud theme" : "Nextcloud تېمىسىنى تەڭشەڭ",
    "Could not set global default apps" : "يەرشارى سۈكۈتتىكى ئەپلەرنى تەڭشىيەلمىدى",
    "Navigation bar settings" : "يولباشچى تاياقچە تەڭشىكى",
    "Default app" : "كۆڭۈلدىكى ئەپ",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "سۈكۈتتىكى ئەپ بولسا ئەپ. كىرگەندىن كېيىن ياكى تىزىملىكتىكى بەلگە چەككەندە ئېچىلدى.",
    "Use custom default app" : "ئىختىيارى كۆڭۈلدىكى ئەپنى ئىشلىتىڭ",
    "Global default app" : "يەرشارى سۈكۈتتىكى ئەپ",
    "Global default apps" : "يەرشارىدىكى سۈكۈتتىكى ئەپلەر",
    "Default app priority" : "كۆڭۈلدىكى ئەپ ئەۋزەللىكى",
    "If an app is not enabled for a user, the next app with lower priority is used." : "ئەگەر بىر ئىشلەتكۈچى ئۈچۈن بىر ئەپ قوزغىتىلمىغان بولسا ، تۆۋەن ئورۇنغا قويۇلغان كېيىنكى ئەپ ئىشلىتىلىدۇ.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "تېمىڭىز سىزنىڭ قوللىشىڭىز ۋە قوللىغان خېرىدارلىرىڭىزنىڭ كۆرۈنۈشى ۋە ھېسسىياتىنى ئاسانلا خاسلاشتۇرالايدۇ. بۇ بارلىق ئىشلەتكۈچىلەر ئۈچۈن كۆرۈنىدۇ.",
    "Name" : "ئاتى",
    "Web link" : "تور ئۇلىنىشى",
    "Slogan" : "شۇئار",
    "a safe home for all your data" : "بارلىق سانلىق مەلۇماتلىرىڭىز ئۈچۈن بىخەتەر ئۆي",
    "Legal notice link" : "قانۇن ئۇقتۇرۇشى",
    "Privacy policy link" : "مەخپىيەتلىك سىياسىتى ئۇلىنىشى",
    "Background and color" : "تەگلىك ۋە رەڭ",
    "Primary color" : "دەسلەپكى رەڭ",
    "Background color" : "تەگلىك رەڭگى",
    "Remove background image" : "تەگلىك سۈرىتىنى ئۆچۈرۈڭ",
    "Background image" : "ئارقا كۆرۈنۈش رەسىمى",
    "Favicon" : "لوگو",
    "Logo" : "لوگو",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "سىز ئۈلگىڭىزنى تاللىسىڭىز ۋە خاسلاشتۇرسىڭىزمۇ ، ئابونتلار ئۇلارنىڭ ئارقا كۆرۈنۈشى ۋە رەڭگىنى ئۆزگەرتەلەيدۇ. خاسلاشتۇرۇشنى ئىجرا قىلماقچى بولسىڭىز ، ئۇنى ئاچسىڭىز بولىدۇ.",
    "Disable user theming" : "ئىشلەتكۈچى باشتېمىسىنى چەكلەڭ",
    "Current selected app: {app}, position {position} of {total}" : "نۆۋەتتىكى تاللانغان ئەپ: {app} ، ئورنى {position} {total}",
    "Move up" : "يۆتكەڭ",
    "Move down" : "تۆۋەنگە يۆتكەڭ",
    "Theme selection is enforced" : "باشتېما تاللاش ئىجرا قىلىنىدۇ",
    "Could not set the app order" : "ئەپ تەرتىپىنى تەڭشىيەلمىدى",
    "Could not reset the app order" : "ئەپ تەرتىپىنى ئەسلىگە كەلتۈرەلمىدى",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "يولباشچى ستونىغا ئىشلىتىلىدىغان ئەپ تەرتىپىنى تەڭشىيەلەيسىز. بىرىنچى تۈر سۈكۈتتىكى ئەپ بولۇپ ، كىرگەندىن كېيىن ياكى بەلگىنى چەككەندە ئېچىلىدۇ.",
    "The default app can not be changed because it was configured by the administrator." : "سۈكۈتتىكى ئەپنى باشقۇرغۇچى تەڭشىگەنلىكى ئۈچۈن ئۆزگەرتكىلى بولمايدۇ.",
    "The app order was changed, to see it in action you have to reload the page." : "ئەپ تەرتىپى ئۆزگەرتىلدى ، ئۇنى ھەرىكەتتە كۆرۈش ئۈچۈن بەتنى قايتا يۈكلىشىڭىز كېرەك.",
    "Reset default app order" : "كۆڭۈلدىكى ئەپ تەرتىپىنى ئەسلىگە كەلتۈرۈڭ",
    "Select a background from your files" : "ھۆججەتلىرىڭىزدىن تەگلىك تاللاڭ",
    "Select background" : "تەگلىكنى تاللاڭ",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "تەگلىك سۈكۈتتىكى سۈكۈتتىكى رەسىم ، ئىختىيارى يۈكلەنگەن رەسىم ياكى ئوچۇق رەڭگە تەڭشىلىدۇ.",
    "Custom background" : "ئىختىيارى تەگلىك",
    "Plain background" : "تۈزلەڭلىك تەگلىكى",
    "Default background" : "سۈكۈتتىكى تەگلىك",
    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "بەزى ئەھۋاللاردا كۇنۇپكا تاختىسىنىڭ تېزلەتمىلىرى قولايلىق قوراللارغا دەخلى قىلىدۇ. قورالىڭىزغا توغرا دىققەت قىلىش ئۈچۈن ، بۇ يەردىكى بارلىق كۇنۇپكا تاختىسىنى چەكلىيەلەيسىز. بۇ يەنە ئەپلەردىكى بارلىق تېزلەتمىلەرنى چەكلەيدۇ.",
    "Disable all keyboard shortcuts" : "بارلىق كۇنۇپكا تاختىسىنى چەكلەڭ",
    "Could not set primary color" : "دەسلەپكى رەڭنى تەڭشىگىلى بولمىدى",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "مۇھىم ئېلېمېنتلارنى گەۋدىلەندۈرۈش ئۈچۈن دەسلەپكى رەڭ بەلگىلەڭ. دەسلەپكى كۇنۇپكىلار قاتارلىق ئېلېمېنتلارغا ئىشلىتىلىدىغان رەڭ قولايلىق بولۇش تەلىپىنى قاندۇرۇش ئۈچۈن تەڭشەلگەندە ئازراق پەرقلىنىشى مۇمكىن.",
    "Reset primary color" : "دەسلەپكى رەڭنى ئەسلىگە كەلتۈرۈڭ",
    "Reset to default" : "سۈكۈتتىكى ھالىتىگە قايتىڭ",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "بىز ئۈچۈن ئومۇميۈزلۈك كىرىش ناھايىتى مۇھىم. بىز تور ئۆلچىمىگە ئەمەل قىلىمىز ۋە ھەممە نەرسىنى ماۋۇسسىز ۋە ئېكران ئوقۇغۇچ قاتارلىق ياردەمچى يۇمشاق دېتاللارسىز ئىشلىتىشكە بولىدىغان قىلىپ تەكشۈرىمىز. بىز AA دەرىجىسىدە {linkstart}تور مەزمۇنىغا ئېرىشىش كۆرسەتمىسى{linkend} 2.1 گە رىئايە قىلىشنى، ھەتتا AAA دەرىجىسىدىمۇ يۇقىرى كونتراستلىق تېمىغا ئەمەل قىلىشنى مەقسەت قىلىمىز.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "ئەگەر مەسىلىگە يولۇقسىڭىز ، ئىككىلەنمەستىن ئۇلارنى {issuetracker} بىزنىڭ مەسىلە ئىز قوغلاش {linkend} on غا دوكلات قىلىڭ. ئەگەر قاتناشماقچى بولسىڭىز ، {designteam} بىزنىڭ لايىھىلەش ئەترىتىمىز {linkend} join غا قوشۇلۇڭ.",
    "Unable to apply the setting." : "بۇ تەڭشەكنى قوللانغىلى بولمىدى.",
    "Appearance and accessibility settings" : "كۆرۈنۈش ۋە زىيارەت قىلىش تەڭشەكلىرى",
    "Misc accessibility options" : "قولايلىق تاللاش تاللانمىلىرى",
    "Enable blur background filter (may increase GPU load)" : "تۇتۇق تەگلىك سۈزگۈچنى قوزغىتىڭ (GPU يۈكىنى ئاشۇرۇشى مۇمكىن)",
    "Customization has been disabled by your administrator" : "باشقۇرغۇچىڭىز تەرىپىدىن خاسلاشتۇرۇش چەكلەنگەن",
    "Disable-user-theming should be true or false" : "چەكلەش-ئىشلەتكۈچى باش تېمىسى راست ياكى يالغان بولۇشى كېرەك",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "دەسلەپكى رەڭ مۇھىم كۇنۇپكىلارغا ئوخشاش ئېلېمېنتلارنى گەۋدىلەندۈرۈشكە ئىشلىتىلىدۇ. ئۇ ھازىرقى رەڭ لايىھىسىگە ئاساسەن ئازراق تەڭشىلىشى مۇمكىن.",
    "Header logo" : "بەت بەلگىسى",
    "Upload new header logo" : "يېڭى ماۋزۇ بەلگىسىنى يۈكلەڭ",
    "Upload new favicon" : "يېڭى favicon نى يۈكلەڭ",
    "User settings" : "ئىشلەتكۈچى تەڭشەكلىرى",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "تەگلىك رەسىمنىڭ ئورنىغا ئاددىي تەگلىك رەڭگىمۇ تەڭشىيەلەيسىز. تەگلىك سۈرىتىنى ئىشلەتسىڭىز بۇ رەڭنى ئۆزگەرتسىڭىز ئەپ تىزىملىكى سىنبەلگىسىنىڭ رەڭگىگە تەسىر كۆرسىتىدۇ.",
    "Upload new logo" : "يېڭى بەلگە يۈكلەڭ",
    "Upload new background and login image" : "يېڭى تەگلىك ۋە كىرىش سۈرىتىنى يۈكلەڭ",
    "Background and login image" : "تەگلىك ۋە كىرىش سۈرىتى",
    "Advanced options" : "ئىلغار تاللاشلار",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "يۈكلەنگەن لوگو ۋە رەڭگە ئاساسەن SVG رەسىملىرىنى قوللاپ ImageMagick PHP كېڭەيتىلمىسىنى قاچىلاڭ.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ھەممىباب زىيارەت قىلىش بىز ئۈچۈن ئىنتايىن مۇھىم. بىز تور ئۆلچىمىگە ئەمەل قىلىپ ، مائۇسسىز ۋە ئېكران ئوقۇغۇچ قاتارلىق ياردەمچى يۇمشاق دېتاللارنىڭ ھەممىسىنى ئىشلىتىشكە بولىدىغانلىقىنى تەكشۈرۈپ تۇرىمىز. بىز AA سەۋىيىسىدىكى {guidelines} تور مەزمۇنىنىڭ زىيارەت قىلىش قوللانمىسى {linkend} 2.1 گە ماسلىشىشنى مەقسەت قىلىمىز ، يۇقىرى سېلىشتۇرما تېمىسى ھەتتا AAA سەۋىيىسىدە.",
    ". Unable to apply the setting." : "بۇ تەڭشەكنى قوللانغىلى بولمىدى.",
    "No background has been selected" : "تەگلىك تاللانمىدى",
    "Select a custom color" : "ئىختىيارى رەڭنى تاللاڭ",
    "Upload" : "يۈكلە"
},
"nplurals=2; plural=(n != 1);");
